package com.ruoyi.cs.service;

import java.util.List;
import com.ruoyi.cs.domain.CsResourceCharging;

/**
 * 资源计费说明Service接口
 * 
 * @author ruoyi
 * @date 2024-05-07
 */
public interface ICsResourceChargingService 
{
    /**
     * 查询资源计费说明
     * 
     * @param resourceChargingId 资源计费说明主键
     * @return 资源计费说明
     */
    public CsResourceCharging selectCsResourceChargingByResourceChargingId(String resourceChargingId);

    /**
     * 查询资源计费说明列表
     * 
     * @param csResourceCharging 资源计费说明
     * @return 资源计费说明集合
     */
    public List<CsResourceCharging> selectCsResourceChargingList(CsResourceCharging csResourceCharging);

    /**
     * 新增资源计费说明
     * 
     * @param csResourceCharging 资源计费说明
     * @return 结果
     */
    public int insertCsResourceCharging(CsResourceCharging csResourceCharging);

    /**
     * 修改资源计费说明
     * 
     * @param csResourceCharging 资源计费说明
     * @return 结果
     */
    public int updateCsResourceCharging(CsResourceCharging csResourceCharging);

    /**
     * 批量删除资源计费说明
     * 
     * @param resourceChargingIds 需要删除的资源计费说明主键集合
     * @return 结果
     */
    public int deleteCsResourceChargingByResourceChargingIds(String[] resourceChargingIds);

    /**
     * 删除资源计费说明信息
     * 
     * @param resourceChargingId 资源计费说明主键
     * @return 结果
     */
    public int deleteCsResourceChargingByResourceChargingId(String resourceChargingId);
}
